AGW Logo

svn SVN Revision 68508 For flatnotebook

This file contains the SVN revision history for flatnotebook, at revision 68508.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 05-Nov-2009 12:25:42 UTC
  • Committer: AG
  • File Size: 213735 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

FlatNotebook: Correct OnMouseWheel for the silly new “true division” behaviour of Python. Thanks to Nat Echols for the bug report.


svn_diff Diff To Previous Version (68362)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/flatnotebook.py       2011/07/24 21:36:47     68362
+++ wxPython/3rdParty/AGW/agw/flatnotebook.py       2011/08/03 18:32:28     68508
@@ -11,7 +11,7 @@
# Python Code By:
#
# Andrea Gavana, @ 02 Oct 2006
# Latest Revision: 12 Sep 2010, 10.00 GMT
#
#
# For All Kind Of Problems, Requests Of Enhancements And Bug Reports, Please
@@ -117,7 +117,7 @@

FlatNotebook is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 12 Sep 2010, 10.00 GMT
+Latest Revision: Andrea Gavana @ 03 Aug 2011, 08.00 GMT

Version 3.1
"""
@@ -5045,7 +5045,7 @@

rotation = event.GetWheelRotation()
delta = event.GetWheelDelta()
-        steps = rotation/delta
+        steps = int(rotation/delta)

for tab in xrange(abs(steps)):
if steps > 0:
@@ -11,7 +11,7 @@
#
# Andrea Gavana, @ 02 Oct 2006
-# Latest Revision: 12 Sep 2010, 10.00 GMT
+# Latest Revision: 03 Aug 2011, 08.00 GMT
#
#
Tree